@@ -72,7 +72,8 @@ class PointBiserialCorrSelector:
         bountries = np.linspace(0, 1, 11, endpoint=True)
         numeric_cols_names = dataframe.select_dtypes(include=np.number).columns.tolist()
         for numeric_col in numeric_cols_names:
-            corr_dict[numeric_col] = self.pointBiserialCorr(dataframe, numeric_col, y_column)
+            if numeric_col != y_column:
+                corr_dict[numeric_col] = self.pointBiserialCorr(dataframe, numeric_col, y_column)
         for i in range(len(bountries)-1):
             corr_levels[str(bountries[i])] = []
             for numeric_col in corr_dict:
@@ -84,4 +85,4 @@ class PointBiserialCorrSelector:
         self.high_corralated = []
         for level in highest_levels:
             self.high_corralated.extend(corr_levels[list(corr_levels.keys())[level]])
-        print(self.high_corralated)
\ No newline at end of file
+        return self.high_corralated
\ No newline at end of file
